==> nan_common_utils-0.0.19.tar.gz: ios/Classes/NanMapView.m <==
//
//  NanMapView.m
//  Runner
//
//  Created by 周泽南 on 2021/8/12.
//

#import "NanMapView.h"
#import "Masonry.h"
#import <MAMapKit/MAMapKit.h>
#import <AMapLocationKit/AMapLocationKit.h>

#define WeakSelf __weak typeof(self) weakSelf = self;
// 字符串为空
#define StringIsEmpty(__string) ((__string.length == 0) || EPObjectIsNil(__string)) || [__string isEqualToString:@"(null)"] || [__string isEqualToString:@"null"]

@interface NanMapView()<MAMapViewDelegate,AMapLocationManagerDelegate>
@property (nonatomic, copy) NSString *myLongitude ;//经度

@property (nonatomic, copy) NSString *myLatitude ; //纬度
//@property (nonatomic,weak) UILabel *titleLabel;
@property (nonatomic, strong) MAMapView *mapView;
@property (nonatomic,copy) NSString *address;
@property (nonatomic, strong) AMapLocationManager *locationManager;
@property (nonatomic,weak) UIImageView *centerImgView;
@property (nonatomic, strong) FlutterBasicMessageChannel *messageChannel;
@end

@implementation NanMapView{
    UIView *_bigView;
}

-(instancetype)initWithFrame:(CGRect)frame viewIdentifier:(int64_t)viewId arguments:(id)args registrar:(NSObject<FlutterPluginRegistrar> *)registrar{
    if (self = [super init]) {
        
        NSString *appkey = args[@"apiKey"];
        [AMapServices sharedServices].apiKey = appkey;
        [self configLocationManager];
        self.messageChannel = [FlutterBasicMessageChannel messageChannelWithName:@"testDidiView2" binaryMessenger:registrar.messenger];
        WeakSelf
//        [self.messageChannel setMessageHandler:^(id  _Nullable message, FlutterReply  _Nonnull callback) {
//            NSString *method = message[@"method"];
//            if ([method isEqualToString:@"haha"]){//开始记录
//                NSDictionary *dic = @{@"address":weakSelf.address,@"longitude":weakSelf.myLongitude,@"latitude":weakSelf.myLatitude};
//                [weakSelf.messageChannel sendMessage:dic];
//            }
//        }];
        [self initUI:frame viewIdentifier:viewId registrar:registrar];
    }
    return self;
}

- (void)configLocationManager
{
    self.locationManager = [[AMapLocationManager alloc] init];
    
    [self.locationManager setDelegate:self];
    
    //设置不允许系统暂停定位
    [self.locationManager setPausesLocationUpdatesAutomatically:NO];
    
    //设置允许在后台定位
    [self.locationManager setAllowsBackgroundLocationUpdates:NO];
    
    //设置允许连续定位逆地理
    [self.locationManager setLocatingWithReGeocode:YES];
    
    [self.locationManager setLocationTimeout:30];
    
    [self.locationManager setReGeocodeTimeout:10];
    
    [self.locationManager setDesiredAccuracy:kCLLocationAccuracyBest];
    [self.locationManager startUpdatingLocation];
}

-(void)initUI:(CGRect)frame viewIdentifier:(int64_t)viewId registrar:(NSObject<FlutterPluginRegistrar> *)registrar{
    _bigView = [[UIView alloc]initWithFrame:frame];
    _bigView.backgroundColor = [UIColor whiteColor];
    
    self.mapView = [[MAMapView alloc] initWithFrame:_bigView.bounds];
    [self.view addSubview:self.mapView];
    self.mapView.showsUserLocation = YES;
    self.mapView.userTrackingMode = MAUserTrackingModeFollow;
     [self.mapView setZoomLevel:18 animated:YES];
    [self.mapView setDelegate:self];
    
    UIImage *centerImg = [UIImage imageNamed:[registrar lookupKeyForAsset:@"packages/nan_common_utils/res/dw.png"]];;//[UIImage imageNamed:@"dw" inBundle:ResourceBundle(@"nan_common_utils") compatibleWithTraitCollection:nil];//[UIImage imageNamed:@"dw"];
    UIImageView *centerImgView = [[UIImageView alloc]initWithImage:centerImg highlightedImage:centerImg];
    self.centerImgView = centerImgView;
    [self.view addSubview:centerImgView];
    [centerImgView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.center.mas_equalTo(_mapView);
        make.width.mas_equalTo(28);
        make.height.mas_equalTo(40);
    }];
    
//    UILabel *titleLabel = [[UILabel alloc]initWithFrame:CGRectZero];
//    self.titleLabel = titleLabel;
//    titleLabel.text = @"测试";
//    titleLabel.backgroundColor = [UIColor whiteColor];
//    [self.view addSubview:titleLabel];
//
//    [titleLabel mas_makeConstraints:^(MASConstraintMaker *make) {
//        make.left.top.right.offset(0);
//        make.height.mas_equalTo(40);
//    }];
}

/* 移动窗口弹一下的动画 */
- (void)centerAnnotationAnimimate
{
    [UIView animateWithDuration:0.5
                          delay:0
                        options:UIViewAnimationOptionCurveEaseOut
                     animations:^{
                         CGPoint center = self.centerImgView.center;
                         center.y -= 20;
                         [self.centerImgView setCenter:center];}
                     completion:nil];
    
    [UIView animateWithDuration:0.45
                          delay:0
                        options:UIViewAnimationOptionCurveEaseIn
                     animations:^{
                         CGPoint center = self.centerImgView.center;
                         center.y += 20;
                         [self.centerImgView setCenter:center];}
                     completion:nil];
}

#pragma mark - AMapLocationManager Delegate
-(void)mapView:(MAMapView *)mapView didUpdateUserLocation:(MAUserLocation *)userLocation updatingLocation:(BOOL)updatingLocation{
    
}

-(void)amapLocationManager:(AMapLocationManager *)manager doRequireLocationAuth:(CLLocationManager *)locationManager{
    [locationManager requestAlwaysAuthorization];
}

-(void)amapLocationManager:(AMapLocationManager *)manager didUpdateLocation:(CLLocation *)location reGeocode:(AMapLocationReGeocode *)reGeocode{
    self.myLongitude = [NSString stringWithFormat:@"%f",location.coordinate.longitude];
    self.myLatitude =  [NSString stringWithFormat:@"%f",location.coordinate.latitude];
    //获取到定位信息，更新annotation
//    if (self.pointAnnotaiton == nil)
//    {
//        self.pointAnnotaiton = [[MAPointAnnotation alloc] init];
//        [self.pointAnnotaiton setCoordinate:location.coordinate];
//        [self.mapView addAnnotation:self.pointAnnotaiton];
//    }
//    [self.pointAnnotaiton setCoordinate:location.coordinate];
    [self.mapView setCenterCoordinate:location.coordinate];
    [_locationManager stopUpdatingLocation];
    CLGeocoder *clGeoCoder = [[CLGeocoder alloc] init];
    CLLocation *currentLocation = [[CLLocation alloc] initWithLatitude:[self.myLatitude doubleValue] longitude:[self.myLongitude doubleValue]];
    /*地理反编码 -- 可以根据地理位置（经纬度）确认位置信息 （街道、门牌）*/
    
    [self reverseGeocodeLocation:clGeoCoder withCurrentLocation:currentLocation];
}

-(void)mapView:(MAMapView *)mapView regionDidChangeAnimated:(BOOL)animated{
    CLLocationDegrees pointssLongitude = mapView.region.center.longitude;//mapView.region.span.longitudeDelta;
    CLLocationDegrees pointssLatitude = mapView.region.center.latitude;//mapView.region.span.latitudeDelta;
//    self.mLongitude = pointssLongitude;
//    self.mLatitude = pointssLatitude;
    self.myLongitude = [NSString stringWithFormat:@"%f",mapView.region.center.longitude];
    self.myLatitude =  [NSString stringWithFormat:@"%f",mapView.region.center.latitude];
    NSLog(@"%@",mapView);

    CLGeocoder *clGeoCoder = [[CLGeocoder alloc] init];
    CLLocation *currentLocation = [[CLLocation alloc] initWithLatitude:pointssLatitude longitude:pointssLongitude];
    /*地理反编码 -- 可以根据地理位置（经纬度）确认位置信息 （街道、门牌）*/
    [self reverseGeocodeLocation:clGeoCoder withCurrentLocation:currentLocation];
    [self centerAnnotationAnimimate];
}

-(void)reverseGeocodeLocation:(CLGeocoder *)clGeoCoder withCurrentLocation:(CLLocation *)currentLocation{
    WeakSelf
    [clGeoCoder reverseGeocodeLocation:currentLocation completionHandler:^(NSArray<CLPlacemark *> * _Nullable placemarks, NSError * _Nullable error) {
        if (placemarks.count >0) {
            CLPlacemark * placeMark = placemarks[0];
            NSArray *formattedAddressLines = placeMark.addressDictionary[@"FormattedAddressLines"];
            weakSelf.address = formattedAddressLines.firstObject;
            NSDictionary *dic = @{@"address":weakSelf.address,@"longitude":weakSelf.myLongitude,@"latitude":weakSelf.myLatitude};
//            weakSelf.titleLabel.text = weakSelf.address;//placeMark.name;
//            [weakSelf.messageChannel sendMessage:dic];
//            NSDictionary *dic = @{@"address":weakSelf.address,@"longitude":weakSelf.myLongitude,@"latitude":weakSelf.myLatitude};
//            if (EPStringIsEmpty(weakSelf.myLongitude) || EPStringIsEmpty(weakSelf.myLatitude)) {
//                return;
//            }
            [weakSelf.messageChannel sendMessage:dic];
        }
        else if (error == nil&&placemarks.count == 0){
        }
        else if (error){
        }
    }];
}

- (nonnull UIView *)view { 
    return _bigView;
}

-(NSString *)returnStringIsEmpty:(NSString *)content{
//    if (((content.length == 0) || EPObjectIsNil(__string)) || [__string isEqualToString:@"(null)"] || [__string isEqualToString:@"null"]) {
//        return @"";
//    }
    return content;
}

@end

==> nan_common_utils-0.0.27.tar.gz: ios/Classes/NanMapView.m <==
//
//  NanMapView.m
//  Runner
//
//  Created by 周泽南 on 2021/8/12.
//

#import "NanMapView.h"
#import "Masonry.h"
#import <MAMapKit/MAMapKit.h>
#import <AMapLocationKit/AMapLocationKit.h>

#define WeakSelf __weak typeof(self) weakSelf = self;
// 字符串为空
#define StringIsEmpty(__string) ((__string.length == 0) || EPObjectIsNil(__string)) || [__string isEqualToString:@"(null)"] || [__string isEqualToString:@"null"]

@interface NanMapView()<MAMapViewDelegate,AMapLocationManagerDelegate>
@property (nonatomic, copy) NSString *myLongitude ;//经度

@property (nonatomic, copy) NSString *myLatitude ; //纬度
@property (nonatomic,weak) UILabel *titleLabel;
@property (nonatomic, strong) MAMapView *mapView;
@property (nonatomic,copy) NSString *address;
@property (nonatomic, strong) AMapLocationManager *locationManager;
@property (nonatomic,weak) UIImageView *centerImgView;
@property (nonatomic, strong) FlutterBasicMessageChannel *messageChannel;
@end

@implementation NanMapView{
    UIView *_bigView;
}

-(instancetype)initWithFrame:(CGRect)frame viewIdentifier:(int64_t)viewId arguments:(id)args registrar:(NSObject<FlutterPluginRegistrar> *)registrar{
    if (self = [super init]) {
        
        NSString *appkey = args[@"apiKey"];
        [AMapServices sharedServices].apiKey = appkey;
        [self configLocationManager];
        self.messageChannel = [FlutterBasicMessageChannel messageChannelWithName:@"testDidiView2" binaryMessenger:registrar.messenger];
        WeakSelf
        [self.messageChannel setMessageHandler:^(id  _Nullable message, FlutterReply  _Nonnull callback) {
            NSString *method = message[@"method"];
            if ([method isEqualToString:@"haha"]){//开始记录
                NSDictionary *dic = @{@"address":weakSelf.address,@"longitude":weakSelf.myLongitude,@"latitude":weakSelf.myLatitude};
                [weakSelf.messageChannel sendMessage:dic];
            }
        }];
        [self initUI:frame viewIdentifier:viewId registrar:registrar];
    }
    return self;
}

- (void)configLocationManager
{
    self.locationManager = [[AMapLocationManager alloc] init];
    
    [self.locationManager setDelegate:self];
    
    //设置不允许系统暂停定位
    [self.locationManager setPausesLocationUpdatesAutomatically:NO];
    
    //设置允许在后台定位
    [self.locationManager setAllowsBackgroundLocationUpdates:NO];
    
    //设置允许连续定位逆地理
    [self.locationManager setLocatingWithReGeocode:YES];
    
    [self.locationManager setLocationTimeout:30];
    
    [self.locationManager setReGeocodeTimeout:10];
    
    [self.locationManager setDesiredAccuracy:kCLLocationAccuracyBest];
    [self.locationManager startUpdatingLocation];
}

-(void)initUI:(CGRect)frame viewIdentifier:(int64_t)viewId registrar:(NSObject<FlutterPluginRegistrar> *)registrar{
    _bigView = [[UIView alloc]initWithFrame:frame];
    _bigView.backgroundColor = [UIColor whiteColor];
    
    self.mapView = [[MAMapView alloc] initWithFrame:_bigView.bounds];
    [self.view addSubview:self.mapView];
    self.mapView.showsUserLocation = YES;
    self.mapView.userTrackingMode = MAUserTrackingModeFollow;
     [self.mapView setZoomLevel:18 animated:YES];
    [self.mapView setDelegate:self];
    
    UIImage *centerImg = [UIImage imageNamed:[registrar lookupKeyForAsset:@"packages/nan_common_utils/res/dw.png"]];;//[UIImage imageNamed:@"dw" inBundle:ResourceBundle(@"nan_common_utils") compatibleWithTraitCollection:nil];//[UIImage imageNamed:@"dw"];
    UIImageView *centerImgView = [[UIImageView alloc]initWithImage:centerImg highlightedImage:centerImg];
    self.centerImgView = centerImgView;
    [self.view addSubview:centerImgView];
    [centerImgView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.center.mas_equalTo(_mapView);
        make.width.mas_equalTo(28);
        make.height.mas_equalTo(40);
    }];
    
    UILabel *titleLabel = [[UILabel alloc]initWithFrame:CGRectZero];
    self.titleLabel = titleLabel;
    titleLabel.text = @"测试";
    titleLabel.backgroundColor = [UIColor whiteColor];
    [self.view addSubview:titleLabel];

    [titleLabel mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.top.right.offset(0);
        make.height.mas_equalTo(40);
    }];
}

/* 移动窗口弹一下的动画 */
- (void)centerAnnotationAnimimate
{
    [UIView animateWithDuration:0.5
                          delay:0
                        options:UIViewAnimationOptionCurveEaseOut
                     animations:^{
                         CGPoint center = self.centerImgView.center;
                         center.y -= 20;
                         [self.centerImgView setCenter:center];}
                     completion:nil];
    
    [UIView animateWithDuration:0.45
                          delay:0
                        options:UIViewAnimationOptionCurveEaseIn
                     animations:^{
                         CGPoint center = self.centerImgView.center;
                         center.y += 20;
                         [self.centerImgView setCenter:center];}
                     completion:nil];
}

#pragma mark - AMapLocationManager Delegate
-(void)mapView:(MAMapView *)mapView didUpdateUserLocation:(MAUserLocation *)userLocation updatingLocation:(BOOL)updatingLocation{
    
}

-(void)amapLocationManager:(AMapLocationManager *)manager doRequireLocationAuth:(CLLocationManager *)locationManager{
    [locationManager requestAlwaysAuthorization];
}

-(void)amapLocationManager:(AMapLocationManager *)manager didUpdateLocation:(CLLocation *)location reGeocode:(AMapLocationReGeocode *)reGeocode{
    self.myLongitude = [NSString stringWithFormat:@"%f",location.coordinate.longitude];
    self.myLatitude =  [NSString stringWithFormat:@"%f",location.coordinate.latitude];
    //获取到定位信息，更新annotation
//    if (self.pointAnnotaiton == nil)
//    {
//        self.pointAnnotaiton = [[MAPointAnnotation alloc] init];
//        [self.pointAnnotaiton setCoordinate:location.coordinate];
//        [self.mapView addAnnotation:self.pointAnnotaiton];
//    }
//    [self.pointAnnotaiton setCoordinate:location.coordinate];
    [self.mapView setCenterCoordinate:location.coordinate];
    [_locationManager stopUpdatingLocation];
    CLGeocoder *clGeoCoder = [[CLGeocoder alloc] init];
    CLLocation *currentLocation = [[CLLocation alloc] initWithLatitude:[self.myLatitude doubleValue] longitude:[self.myLongitude doubleValue]];
    /*地理反编码 -- 可以根据地理位置（经纬度）确认位置信息 （街道、门牌）*/
    
    [self reverseGeocodeLocation:clGeoCoder withCurrentLocation:currentLocation];
}

-(void)mapView:(MAMapView *)mapView regionDidChangeAnimated:(BOOL)animated{
    CLLocationDegrees pointssLongitude = mapView.region.center.longitude;//mapView.region.span.longitudeDelta;
    CLLocationDegrees pointssLatitude = mapView.region.center.latitude;//mapView.region.span.latitudeDelta;
//    self.mLongitude = pointssLongitude;
//    self.mLatitude = pointssLatitude;
    self.myLongitude = [NSString stringWithFormat:@"%f",mapView.region.center.longitude];
    self.myLatitude =  [NSString stringWithFormat:@"%f",mapView.region.center.latitude];
    NSLog(@"%@",mapView);

    CLGeocoder *clGeoCoder = [[CLGeocoder alloc] init];
    CLLocation *currentLocation = [[CLLocation alloc] initWithLatitude:pointssLatitude longitude:pointssLongitude];
    /*地理反编码 -- 可以根据地理位置（经纬度）确认位置信息 （街道、门牌）*/
    [self reverseGeocodeLocation:clGeoCoder withCurrentLocation:currentLocation];
    [self centerAnnotationAnimimate];
}

-(void)reverseGeocodeLocation:(CLGeocoder *)clGeoCoder withCurrentLocation:(CLLocation *)currentLocation{
    WeakSelf
    [clGeoCoder reverseGeocodeLocation:currentLocation completionHandler:^(NSArray<CLPlacemark *> * _Nullable placemarks, NSError * _Nullable error) {
        if (placemarks.count >0) {
            CLPlacemark * placeMark = placemarks[0];
            NSArray *formattedAddressLines = placeMark.addressDictionary[@"FormattedAddressLines"];
            weakSelf.address = formattedAddressLines.firstObject;
            NSDictionary *dic = @{@"address":weakSelf.address,@"longitude":weakSelf.myLongitude,@"latitude":weakSelf.myLatitude};
            weakSelf.titleLabel.text = weakSelf.address;//placeMark.name;
//            [weakSelf.messageChannel sendMessage:dic];
//            NSDictionary *dic = @{@"address":weakSelf.address,@"longitude":weakSelf.myLongitude,@"latitude":weakSelf.myLatitude};
//            if (EPStringIsEmpty(weakSelf.myLongitude) || EPStringIsEmpty(weakSelf.myLatitude)) {
//                return;
//            }
//            [weakSelf.messageChannel sendMessage:dic];
        }
        else if (error == nil&&placemarks.count == 0){
        }
        else if (error){
        }
    }];
}

- (nonnull UIView *)view { 
    return _bigView;
}

-(NSString *)returnStringIsEmpty:(NSString *)content{
//    if (((content.length == 0) || EPObjectIsNil(__string)) || [__string isEqualToString:@"(null)"] || [__string isEqualToString:@"null"]) {
//        return @"";
//    }
    return content;
}

@end
